@@ -1,7 +1,7 @@
 /*----------------------------------------------------------------------------
 --                                  G P S                                   --
 --                                                                          --
---                     Copyright (C) 2008-2013, AdaCore                     --
+--                     Copyright (C) 2008-2019, AdaCore                     --
 --                                                                          --
 -- This is free software;  you can redistribute it  and/or modify it  under --
 -- terms of the  GNU General Public License as published  by the Free Soft- --
@@ -15,7 +15,7 @@
 -- of the license.                                                          --
 ----------------------------------------------------------------------------*/
 
-#include <gtk/gtktextbuffer.h>
+#include <gtk/gtk.h>
 
 void* replace_insert_text
    (struct _GtkTextBufferClass* class, void* insert_func)
